## Ansættelseskontrakt

Mellem undertegnede

<company-name>Nordic Software Solutions ApS</company-name>
Bredgade 34, 3. th., 9492 Blokhus  
CVR-nr.: 38910243  
(herefter kaldet virksomheden)

og

Charlotte Madsen  
Hesthavevej 19, 1. tv., 6933 Kibæk  
(herefter kaldt medarbejderen)

indgås følgende ansættelsesaftale.

<start-date>
## [SECTION-IDX]. Tiltrædelse

Medarbejderen tiltræder stillingen 1. august 2024.
</start-date>

<location>
## [SECTION-IDX]. Arbejdssted

Arbejdsstedet er beliggende på virksomhedens kontor, Bredgade 34, 3. th., 8654 Bryrup.
</location>

<title>
## [SECTION-IDX]. Stillingsbetegnelse

Medarbejderen er ansat som Frontend Udvikler.
</title>

## [SECTION-IDX]. Arbejdsopgaver

Medarbejderen skal primært beskæftige sig med udvikling og vedligeholdelse af webapplikationer, herunder brug af React, samarbejde med backend-teamet og deltagelse i designmøder. Arbejdsopgaverne kan til enhver tid ændres i takt med virksomhedens behov.

<trial-period>
Der er ikke aftalt prøvetid for denne ansættelse.
</trial-period>

<salary>
## [SECTION-IDX]. Løn

Medarbejderen aflønnes med en årlig bruttoløn på kr. 540.000 (før skat og pension), svarende til kr. 45.000 pr. måned. Lønnen udbetales bagud, senest sidste hverdag i måneden, til medarbejderens oplyste bankkonto.

Lønnen revurderes en gang årligt pr. 1. januar.
</salary>

<pension>
## [SECTION-IDX]. Pension

Virksomheden har oprettet en pensionsordning for medarbejderen i PFA Pension. Virksomheden indbetaler 8% af den faste løn, og medarbejderen indbetaler 4%. Bidragene beregnes af den samlede bruttoløn.
</pension>

<social-security>
## [SECTION-IDX]. Sociale sikringsbidrag

Virksomheden indbetaler alle lovpligtige sociale sikringsbidrag, herunder ATP og bidrag til barselsfonden, i overensstemmelse med gældende dansk lovgivning.
</social-security>

<work-time>
## [SECTION-IDX]. Arbejdstid

Den aftalte ugentlige arbejdstid udgør 37 timer, eksklusive frokostpause. Arbejdstiden tilrettelægges i samråd med ledelsen og placeres i virksomhedens normale åbningstid. Lønnen tager højde for nødvendigt merarbejde. Ved væsentligt merarbejde indgås særskilt aftale om afspadsering eller honorering.
</work-time>

<holiday>
## [SECTION-IDX]. Ferie

Medarbejderen har ret til betalt ferie efter ferielovens regler. Det lovpligtige ferietillæg udbetales med 2,08% i forbindelse med den månedlige lønudbetaling.

Juleaftensdag og nytårsaftensdag er fridage med fuld løn.
</holiday>

<extra-holiday>
## [SECTION-IDX]. Feriefridage

Der ydes ikke yderligere feriefridage ud over den lovbestemte ferie.
</extra-holiday>

<training>
## [SECTION-IDX]. Efteruddannelse

Medarbejderen har mulighed for efter- og videreuddannelse, såfremt dette anses for relevant for arbejdsopgaverne og aftales nærmere med virksomheden.
</training>

<illness>
## [SECTION-IDX]. Sygdom

Fravær grundet sygdom skal meddeles til arbejdsgiveren så tidligt som muligt på første sygedag. Ved fravær, der strækker sig ud over tre dage, kan arbejdsgiveren kræve lægeerklæring, som virksomheden betaler. Medarbejderen har ret til fuld løn under sygdom.
</illness>

<parental-leave>
## [SECTION-IDX]. Graviditet, barsel og forældreorlov

Medarbejderen har ret til barsels- og forældreorlov efter barselsloven.

Virksomheden yder fuld løn til mor under følgende perioder:

- 4 uger før forventet fødsel  
- 14 uger efter fødsel

Til far/medmor ydes der fuld løn i 2 uger efter fødsel.

Retten til løn under barsel og forældreorlov gælder også i tilfælde af adoption, i henhold til gældende lovgivning.
</parental-leave>

## [SECTION-IDX]. Barns sygdom

Medarbejderen har ret til 2 dages frihed med løn pr. barn pr. år ved barns sygdom.

## [SECTION-IDX]. Tavshedspligt og loyalitet

Medarbejderen har under ansættelsen og efter fratrædelse tavshedspligt om virksomhedens forhold, herunder forretningshemmeligheder og oplysninger, der ikke er offentligt kendte eller alment tilgængelige. Denne forpligtelse gælder også efter ansættelsesforholdets ophør.

<termination>
## [SECTION-IDX]. Opsigelse

Ansættelsesforholdet kan opsiges af såvel medarbejderen som virksomheden i henhold til funktionærlovens varsler. For begge parter gælder et gensidigt opsigelsesvarsel på 90 dage til udgangen af en måned. Opsigelsen skal ske skriftligt.
</termination>

<collective-agreement>
## [SECTION-IDX]. Kollektiv overenskomst

Dette ansættelsesforhold er ikke omfattet af en kollektiv overenskomst.
</collective-agreement>

## [SECTION-IDX]. Retsgrundlag

Ansættelsesforholdet reguleres af dansk ret, herunder funktionærloven og ferieloven, i det omfang ovenstående ikke stiller medarbejderen bedre.

Blokhus, den 25. maj 2024

Medarbejderen _____________________________________

Virksomheden _____________________________________